{% raw %}
{% load mote_tags %}
{% mask element.json.data.Navigation as "nav" %}
<div class="navigation">
  <h4 class="heading heading--large">
    <a href="/" class="navigation__anchor">Home</a>
  </h4>
  <ul class="nav-list nav-list--column">
    {% for item in nav.nav_list %}
      <li class="nav-list__item nav-list__item--column">
        <a href="{{item.href}}" class="nav-list__anchor nav-list__anchor--column">
          {{item.name}}
        </a>
        <span class="nav-list__anchor-desc nav-list__anchor-desc--column">{{item.desc}}</span>
      </li>
    {% endfor %}
  </ul>
</div>
{% endraw %}
