{% raw %}
<div class="teaser-meta-list">
  <div class="teaser-meta-list__comment-counter">
    12 <span class="teaser-meta-list__comment-label-icon">comments</span>
  </div>
  <div class="article-teaser-list__reply-counter">
    4 <span class="article-teaser-list__reply-label">reply</span>
  </div>
</div>
{% endraw %}
