# -*- coding: utf-8 -*-
# Generated by Django 1.9.9 on 2016-08-30 09:54
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('profiles', '0005_add_security_questions_model'),
    ]

    operations = [
        migrations.AddField(
            model_name='userprofilessettings',
            name='security_questions_required',
            field=models.BooleanField(default=False, verbose_name='Security questions required'),
        ),
        migrations.AddField(
            model_name='userprofilessettings',
            name='show_security_question_fields',
            field=models.BooleanField(default=False, verbose_name='Add security question fields to registration'),
        ),
    ]
