{% load wagtailcore_tags core_tags wagtailimages_tags %}
{% if article.get_effective_image %}
<a href="{% pageurl article %}" class="{{layouttype}}-teaser__thumbnail-link">
  {% image article.get_effective_image fill-96x96 as teaser_thumbnail %}
  <img alt="{{article.get_effective_image}}" src="{{ teaser_thumbnail.url }}" class="{{layouttype}}-teaser__thumbnail" />
</a>
{% endif %}
