# -*- coding: utf-8 -*-
# Generated by Django 1.9.13 on 2017-06-07 13:32
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0061_add_success_fields_to_reaction_choice'),
    ]

    operations = [
        migrations.AlterField(
            model_name='reactionquestionchoice',
            name='success_message',
            field=models.CharField(blank=True, max_length=1000, null=True),
        ),
    ]
